==> haskell-gridtables-0.1.1.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gridtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gridtables
version:              0.1.1.0
visibility:           public
id:                   gridtables-0.1.1.0-FqNwBe1i88u3jldvaFiCh1
key:                  gridtables-0.1.1.0-FqNwBe1i88u3jldvaFiCh1
license:              MIT
copyright:            © 2022-2023 Posit Software, PBC
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/gridtables
synopsis:             Parser for reStructuredText-style grid tables.
description:
    Provides a parser for plain-text representations of
    tables. This package supports table headers, cells
    spanning multiple columns or rows, as well as a way
    to specfiy column alignments.

category:             Text
abi:                  7696afd941979913f5d575bc7b2ae874
exposed:              True
exposed-modules:
    Text.GridTable Text.GridTable.ArrayTable Text.GridTable.Parse
    Text.GridTable.Trace

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gridtables-0.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gridtables-0.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gridtables-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gridtables
hs-libraries:         HSgridtables-0.1.1.0-FqNwBe1i88u3jldvaFiCh1
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7
    doclayout-0.5-3uEvNcwSawAKaZhYDKWTsB parsec-3.1.16.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-gridtables/html/gridtables.haddock
haddock-html:         /usr/share/doc/haskell-gridtables/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gridtables-0.1.1.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gridtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gridtables
version:              0.1.1.0
visibility:           public
id:                   gridtables-0.1.1.0-6JTGgrlO7ziIzA8BpRNv0x
key:                  gridtables-0.1.1.0-6JTGgrlO7ziIzA8BpRNv0x
license:              MIT
copyright:            © 2022-2023 Posit Software, PBC
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/gridtables
synopsis:             Parser for reStructuredText-style grid tables.
description:
    Provides a parser for plain-text representations of
    tables. This package supports table headers, cells
    spanning multiple columns or rows, as well as a way
    to specfiy column alignments.

category:             Text
abi:                  d8663a7e0a0d5b0808ba3bc98696da68
exposed:              True
exposed-modules:
    Text.GridTable Text.GridTable.ArrayTable Text.GridTable.Parse
    Text.GridTable.Trace

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gridtables-0.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gridtables-0.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gridtables-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gridtables
hs-libraries:         HSgridtables-0.1.1.0-6JTGgrlO7ziIzA8BpRNv0x
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7
    doclayout-0.5-AzY66xM6VCn9pf7z28gwqH parsec-3.1.16.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-gridtables/html/gridtables.haddock
haddock-html:         /usr/share/doc/haskell-gridtables/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
